==> huaweicloudsdkdataartsstudio-3.1.140-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/url_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UrlDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'contains': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'contains': 'contains'
    }

    def __init__(self, name=None, contains=None):
        """UrlDTO

        The model defined in huaweicloud sdk

        :param name: url路径名称
        :type name: str
        :param contains: 父权限集是否包含此权限, true包含, false不包含, null未检测
        :type contains: bool
        """
        
        

        self._name = None
        self._contains = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if contains is not None:
            self.contains = contains

    @property
    def name(self):
        """Gets the name of this UrlDTO.

        url路径名称

        :return: The name of this UrlDTO.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UrlDTO.

        url路径名称

        :param name: The name of this UrlDTO.
        :type name: str
        """
        self._name = name

    @property
    def contains(self):
        """Gets the contains of this UrlDTO.

        父权限集是否包含此权限, true包含, false不包含, null未检测

        :return: The contains of this UrlDTO.
        :rtype: bool
        """
        return self._contains

    @contains.setter
    def contains(self, contains):
        """Sets the contains of this UrlDTO.

        父权限集是否包含此权限, true包含, false不包含, null未检测

        :param contains: The contains of this UrlDTO.
        :type contains: bool
        """
        self._contains = contains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UrlDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/url_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UrlDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'contains': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'contains': 'contains'
    }

    def __init__(self, name=None, contains=None):
        r"""UrlDTO

        The model defined in huaweicloud sdk

        :param name: url路径名称
        :type name: str
        :param contains: 父权限集是否包含此权限, true包含, false不包含, null未检测
        :type contains: bool
        """
        
        

        self._name = None
        self._contains = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if contains is not None:
            self.contains = contains

    @property
    def name(self):
        r"""Gets the name of this UrlDTO.

        url路径名称

        :return: The name of this UrlDTO.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this UrlDTO.

        url路径名称

        :param name: The name of this UrlDTO.
        :type name: str
        """
        self._name = name

    @property
    def contains(self):
        r"""Gets the contains of this UrlDTO.

        父权限集是否包含此权限, true包含, false不包含, null未检测

        :return: The contains of this UrlDTO.
        :rtype: bool
        """
        return self._contains

    @contains.setter
    def contains(self, contains):
        r"""Sets the contains of this UrlDTO.

        父权限集是否包含此权限, true包含, false不包含, null未检测

        :param contains: The contains of this UrlDTO.
        :type contains: bool
        """
        self._contains = contains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UrlDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
